==> 1.0.0.zip: terraform-provider-dynamix/samples/cloudapi/disk/data_disk_list_deleted/main.tf <==
/*
Пример использования
Получение списка дисков со статусом DELETED
*/

#Раскомментируйте этот код,
#и внесите необходимые правки в версию и путь,
#чтобы работать с установленным вручную (не через hashicorp provider registry) провайдером
/*
terraform {
  required_providers {
    dynamix = {
      source  = "basistech.ru/tf/dynamix"
      version = "<VERSION>"
    }
  }
}
*/

provider "dynamix" {
  authenticator = "decs3o"
  #controller_url = <DECORT_CONTROLLER_URL>
  controller_url = "https://ds1.digitalenergy.online"
  #oauth2_url = <DECORT_SSO_URL>
  oauth2_url           = "https://sso.digitalenergy.online"
  allow_unverified_ssl = true
}

data "dynamix_disk_list_deleted" "dld" {
  #фильтр по id диска
  #опциональный параметр
  #тип - целое число
  #by_id = 100
 
  #фильтр по имени диска
  #опциональный параметр
  #тип - строка
  #name = "data_disk"

  #фильтр по имени аккаунта
  #опциональный параметр
  #тип - строка
  #account_name = "user"
  
  #фильтр по максимальному размеру диска
  #опциональный параметр
  #тип - целое число
  #disk_max_size = 100

  #фильтр по доступности иным пользователям
  #опциональный параметр
  #тип - булев
  #shared = false

  #id аккаунта для получения списка дисков
  #опциональный параметр 
  #тип - целое число
  #account_id = 11111

  #тип диска
  #опциональный параметр 
  #тип - строка
  #возможные типы: "b" - boot_disk, "d" - data_disk
  #type = "d"

  #сортировка по одному из поддерживаемых полей
  #опциональный параметр
  #тип - строка
  #формат - "+поле" по возрастанию / "-поле" по убыванию
  #sort_by = "+name"

  #кол-во страниц для вывода
  #опицональный параметр 
  #тип - целое число
  #page = 1

  #размер страницы
  #опицональный параметр 
  #тип - целое число
  #size = 1
}

output "test" {
  value = data.dynamix_disk_list_deleted.dld
}

==> 1.2.1.zip: terraform-provider-dynamix/samples/cloudapi/disk/data_disk_list_deleted/main.tf <==
/*
Пример использования
Получение списка дисков со статусом DELETED
*/

#Раскомментируйте этот код,
#и внесите необходимые правки в версию и путь,
#чтобы работать с установленным вручную (не через hashicorp provider registry) провайдером
/*
terraform {
  required_providers {
    dynamix = {
      source  = "basistech.ru/tf/dynamix"
      version = "<VERSION>"
    }
  }
}
*/

provider "dynamix" {
  authenticator = "decs3o"
  #controller_url = <DYNAMIX_CONTROLLER_URL>
  controller_url = "https://ds1.digitalenergy.online"
  #oauth2_url = <DYNAMIX_OAUTH2_URL>
  oauth2_url           = "https://sso.digitalenergy.online"
  allow_unverified_ssl = true
}

data "dynamix_disk_list_deleted" "dld" {
  #фильтр по id диска
  #опциональный параметр
  #тип - целое число
  #by_id = 100
 
  #фильтр по имени диска
  #опциональный параметр
  #тип - строка
  #name = "data_disk"

  #фильтр по имени аккаунта
  #опциональный параметр
  #тип - строка
  #account_name = "user"
  
  #фильтр по максимальному размеру диска
  #опциональный параметр
  #тип - целое число
  #disk_max_size = 100

  #фильтр по доступности иным пользователям
  #опциональный параметр
  #тип - булев
  #shared = false

  #id аккаунта для получения списка дисков
  #опциональный параметр 
  #тип - целое число
  #account_id = 11111

  #тип диска
  #опциональный параметр 
  #тип - строка
  #возможные типы: "b" - boot_disk, "d" - data_disk
  #type = "d"

  #сортировка по одному из поддерживаемых полей
  #опциональный параметр
  #тип - строка
  #формат - "+поле" по возрастанию / "-поле" по убыванию
  #sort_by = "+name"

  #кол-во страниц для вывода
  #опицональный параметр 
  #тип - целое число
  #page = 1

  #размер страницы
  #опицональный параметр 
  #тип - целое число
  #size = 1
}

output "test" {
  value = data.dynamix_disk_list_deleted.dld
}
